Bitmap class

Bitmap class provides a wrapper around the bitmap package for Android platform.

Constructors

Bitmap()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromProvider(NetworkImage image, int width) Future<Uint8List>
Process and convert a NetworkImage to a Uint8List suitable for printing Maintains aspect ratio and handles transparency
getImageDimensions(String url) Future<Image?>
Get the dimensions of an image from a URL