Bitmap class

Bitmap class provides a stub implementation for web platform

Constructors

Bitmap()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromProvider(NetworkImage image, int width) Future<Uint8List>
Process and convert a NetworkImage to a Uint8List suitable for printing Returns an empty Uint8List since this functionality is not available on web
getImageDimensions(String url) Future<Image?>
Get the dimensions of an image from a URL Returns null since this functionality is not available on web