getImageDimensions static method

Future<Image?> getImageDimensions(
  1. String url
)

Get the dimensions of an image from a URL Returns null since this functionality is not available on web

Implementation

static Future<ui.Image?> getImageDimensions(String url) async {
  print("We're in Web, nothing to do here!");
  return null;
}