Sumup class

Wrapper class for SumUp payment processing functionality on Android

Constructors

Sumup()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkout(SumupPaymentRequest paymentRequest) Future<SumupPluginCheckoutResponse>
Process a payment checkout
init(String affiliateKey) Future<SumupPluginResponse>
Initialize SumUp with affiliate key
isLoggedIn() Future<bool?>
Check if user is logged in to SumUp
login() Future<SumupPluginResponse>
Login to SumUp
loginWithToken(String token) Future<SumupPluginResponse>
Login to SumUp with a token
logout() Future<SumupPluginResponse>
Logout from SumUp
merchant() Future<SumupPluginMerchantResponse>
Get merchant information
openSettings() Future<SumupPluginResponse>
Open SumUp settings
prepareForCheckout() Future<SumupPluginResponse>
Prepare for checkout