SumupPaymentRequest class
Payment request wrapper for SumUp
Constructors
- SumupPaymentRequest(SumupPayment payment)
- Constructor for SumupPaymentRequest
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- payment → SumupPayment
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toSumupPaymentRequest(
) → SumupPaymentRequest - Convert to native SumUp payment request
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited