sunmiscannerimports_web library

Classes

SunmiScanner
SunmiScanner class provides a stub implementation for web platform since the sunmi_scanner package only works on Android.

Enums

KeyAction
KeyAction enum for web implementation Mirrors the enum from sunmi_scanner package