SunmiScanner class

SunmiScanner class provides a stub implementation for web platform since the sunmi_scanner package only works on Android.

Constructors

SunmiScanner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getScannerModel() Future<int?>
Get the scanner model Returns a Future
isScannerAvailable() Future<bool?>
Check if scanner is available Returns a Future
onBarcodeScanned() Stream<String>
Listen to barcode scan events Returns an empty Stream since this functionality is not available on web
scan() Future<void>
Start scanning - stub implementation for web
sendKeyEvent(Object action, int keyCode) Future<void>
Send key event to scanner - stub implementation for web action - KeyAction enum (UP or DOWN) keyCode - Key code to send
stop() Future<void>
Stop scanning - stub implementation for web