onBarcodeScanned static method

Stream<String> onBarcodeScanned()

Listen to barcode scan events Returns an empty Stream since this functionality is not available on web

Implementation

static Stream<String> onBarcodeScanned() {
  print("We're in Web, nothing to do here!");
  // Return an empty stream that never emits any values
  return Stream<String>.empty();
}