SumupPayment class
Payment data class for SumUp payments
Constructors
Properties
- currency → String
-
final
- foreignTransactionId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saleItemsCount → int
-
final
- skipSuccessScreen → bool
-
final
- tip → double?
-
final
- title → String
-
final
- total → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toSumupPayment(
) → SumupPayment - Convert to native SumUp payment object
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited