Sumup class
Wrapper class for SumUp payment processing functionality on web
Constructors
- Sumup()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkout(
SumupPaymentRequest payment) → Future< SumupPluginCheckoutResponse> - Process a payment checkout (stub implementation for web)
-
init(
String affiliateKey) → Future< SumupPluginResponse> - Initialize SumUp with affiliate key (stub implementation for web)
-
isLoggedIn(
) → Future< bool?> - Check if user is logged in to SumUp (stub implementation for web)
-
login(
) → Future< SumupPluginResponse> - Login to SumUp (stub implementation for web)
-
loginWithToken(
String token) → Future< SumupPluginResponse> - Login to SumUp with a token (stub implementation for web)
-
logout(
) → Future< SumupPluginResponse> - Logout from SumUp (stub implementation for web)
-
merchant(
) → Future< SumupPluginMerchantResponse> - Get merchant information (stub implementation for web)
-
openSettings(
) → Future< SumupPluginResponse> - Open SumUp settings (stub implementation for web)
-
prepareForCheckout(
) → Future< SumupPluginResponse> - Prepare for checkout (stub implementation for web)