SunmiPrinter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bindingPrinter(
) → Future< bool?> -
bold(
) → dynamic -
cut(
) → dynamic -
exitTransactionPrint(
) → dynamic -
line(
{int len = 1}) → dynamic -
lineWrap(
int count) → dynamic -
printImage(
Uint8List image) → dynamic -
printQRCode(
String data) → dynamic -
printRow(
{List< Object> cols = const []}) → dynamic -
printText(
String text) → dynamic -
resetBold(
) → dynamic -
resetFontSize(
) → dynamic -
setAlignment(
Object alignment) → dynamic -
setCustomFontSize(
int size) → dynamic -
setFontSize(
Object fontSize) → dynamic -
startTransactionPrint(
) → dynamic -
submitTransactionPrint(
) → dynamic